export type Locale = string;
export type LoadResult<V = string> = {
    [K in string]: LoadResult<V> | V;
};
export type LoadFunction = (locale: Locale) => Promise<LoadResult | undefined>;
type Key = string;
type Route = string | RegExp;
type FormatFunction = (params?: FormatParams) => string;
type PrepareFunction = (locale: Locale, format: string) => FormatFunction;
export type LoaderModule = {
    /**
     * Represents the translation namespace. This key is used as a translation prefix so it should be module-unique. You can access your translation later using `$t('key.yourTranslation')`. It shouldn't include `.` (dot) character.
     */
    key: Key;
    /**
     * Function returning a `Promise` with translation data. You can use it to load files locally, fetch it from your API etc...
     */
    load: LoadFunction;
    /**
     * Prepare function for the format. Default is `prepareNamedFormat`.
     */
    prepare?: PrepareFunction;
    /**
     * Define routes this loader should be triggered for. You can use Regular expressions too. For example `[/\/.ome/]` will be triggered for `/home` and `/rome` route as well (but still only once). Leave this `undefined` in case you want to load this module with any route (useful for common translations).
     * Regex or prefix of the route
     */
    routes?: Route[];
};
type Logger = Pick<Console, 'error' | 'warn' | 'info' | 'debug' | 'trace'>;
export interface ServiceConfig {
    locales?: Locale[];
    activeLocale?: Locale;
    prepare?: PrepareFunction;
    loaders?: LoaderModule[];
    logger?: Logger;
}
export type FormatParams = Record<string, any>;
export type TextFunction = (key: string, params?: FormatParams) => string;
export interface ILocalizationService {
    readonly locales: Locale[];
    getActiveLocale(): Locale | undefined;
    setActiveLocale(locale: string): void;
    loadLocalizations(pathname: string): Promise<void>;
    text: TextFunction;
    getPSText(prefix: string | undefined, suffix?: string): TextFunction;
}
export declare class LocalizationService implements ILocalizationService {
    #private;
    constructor(config: ServiceConfig);
    get locales(): string[];
    getActiveLocale: () => string | undefined;
    setActiveLocale: (locale: Locale) => void;
    text: TextFunction;
    getPSText: (prefix: string | undefined, suffix?: string) => (key: string, params?: FormatParams) => string;
    loadLocalizations: (pathname: string) => Promise<void>;
    private getRelevantLoaders;
    private flattenLocalizationWithPrefix;
    private flattenLocalization;
}
export declare const prepareNamedFormat: PrepareFunction;
export declare const prepareICUFormat: PrepareFunction;
export {};
